#[repr(i32)]pub enum Mode {
PvmEnabled = 0,
PvmMarker = 1,
PvmRemoved = 2,
PvmDisabled = 3,
}Expand description
enumerates all supported patch configurations
Variants
PvmEnabled = 0
both patch and prior code present behind workflow versioning
PvmMarker = 1
only patch code present, workflow version marker present
PvmRemoved = 2
only patch code present, workflow version marker removed
PvmDisabled = 3
only prior code present, no patch code or workflow version marker introduced
Implementations
Sourceimpl Mode
impl Mode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.