#[repr(i32)]pub enum Version {
PvUnspecified = 0,
Pv64 = 1,
}Expand description
enumerates all defined patch versions
Variants
PvUnspecified = 0
Pv64 = 1
wraps expression evaluation in local activities within workflow contexts details: https://cludden.github.io/protoc-gen-go-temporal/docs/guides/fix-versions#fix_version_64_expression_evaluation_local_activity
Implementations
Sourceimpl Version
impl Version
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.