pub struct ActivityOptions {
pub name: String,
pub task_queue: String,
pub schedule_to_close_timeout: Option<Duration>,
pub schedule_to_start_timeout: Option<Duration>,
pub start_to_close_timeout: Option<Duration>,
pub heartbeat_timeout: Option<Duration>,
pub wait_for_cancellation: bool,
pub retry_policy: Option<RetryPolicy>,
}Expand description
ActivityOptions identifies an rpc method as a Temporal activity definition, and describes available activity configuration options
Fields
name: StringFully-qualified activity name
task_queue: StringOverride default task queue for activity
schedule_to_close_timeout: Option<Duration>Total time that a workflow is willing to wait for Activity to complete
schedule_to_start_timeout: Option<Duration>Time that the Activity Task can stay in the Task Queue before it is picked up by a Worker
start_to_close_timeout: Option<Duration>Maximum time of a single Activity execution attempt
heartbeat_timeout: Option<Duration>Heartbeat interval. Activity must call Activity.RecordHeartbeat(ctx, “my-heartbeat”)
wait_for_cancellation: boolWaitForCancellation - Whether to wait for canceled activity to be completed (activity can be failed, completed, cancel accepted)
retry_policy: Option<RetryPolicy>Specifies how to retry an Activity if an error occurs