pub struct Patch {
pub version: i32,
pub mode: i32,
}Expand description
Patch describes how a nondeterministic fix/feature introduced to generated code is implemented. By default, all patches are introduced in PVM_ENABLED mode. Once rollout of updated code has been completed and old workflows have closed and retention window passed (or certain that replay is no longer a risk), the prior code can be removed by switching to PVM_MARKER or removed entirely with PVM_REMOVED. Patch code can also be disabled explicitly using PVM_DISABLED.
Fields
version: i32mode: i32Implementations
Sourceimpl Patch
impl Patch
Sourcepub fn version(&self) -> Version
pub fn version(&self) -> Version
Returns the enum value of version, or the default if the field is set to an invalid enum value.
Sourcepub fn set_version(&mut self, value: Version)
pub fn set_version(&mut self, value: Version)
Sets version to the provided enum value.