pub struct QueryOptions {
pub cli: Option<CliCommandOptions>,
pub name: String,
pub xns: Option<XnsActivityOptions>,
pub patches: Vec<Patch>,
}Expand description
QueryOptions identifies an rpc method as a Temporal query definition, and describes available query configuration options
Fields
cli: Option<CliCommandOptions>cli command overrides
name: StringFully-qualified query name
xns: Option<XnsActivityOptions>XNS can be used to configure default activity options for xns workflow executions
patches: Vec<Patch>Configure patches, by default, patches are introduced in enabled mode