pub struct SignalOptions {
pub cli: Option<CliCommandOptions>,
pub name: String,
pub xns: Option<XnsActivityOptions>,
pub patches: Vec<Patch>,
}Expand description
SignalOptions identifies an rpc method as a Temporal singal definition, and describes available signal configuration options
Fields
cli: Option<CliCommandOptions>cli command overrides
name: StringFully-qualified signal name
xns: Option<XnsActivityOptions>XNS can be used to configure default activity options for xns workflow executions
patches: Vec<Patch>Configure patches, by default, patches are introduced in enabled mode