pub struct UpdateOptions {
pub cli: Option<CliCommandOptions>,
pub id: String,
pub name: String,
pub patches: Vec<Patch>,
pub validate: bool,
pub wait_for_stage: i32,
pub wait_policy: i32,
pub xns: Option<XnsActivityOptions>,
}Expand description
UpdateOptions identifies an rpc method as a Temporal update definition, and describes available update configuration options
Fields
cli: Option<CliCommandOptions>cli command overrides
id: StringID expression
name: StringFully-qualified update name
patches: Vec<Patch>Configure patches, by default, patches are introduced in enabled mode
validate: boolInclude validation hook
wait_for_stage: i32Default wait policy if not specified
wait_policy: i32👎Deprecated
xns: Option<XnsActivityOptions>XNS can be used to configure default activity options for xns workflow executions
Implementations
Sourceimpl UpdateOptions
impl UpdateOptions
Sourcepub fn wait_policy(&self) -> WaitPolicy
pub fn wait_policy(&self) -> WaitPolicy
Returns the enum value of wait_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_wait_policy(&mut self, value: WaitPolicy)
pub fn set_wait_policy(&mut self, value: WaitPolicy)
Sets wait_policy to the provided enum value.
Sourcepub fn wait_for_stage(&self) -> WaitPolicy
pub fn wait_for_stage(&self) -> WaitPolicy
Returns the enum value of wait_for_stage, or the default if the field is set to an invalid enum value.
Sourcepub fn set_wait_for_stage(&mut self, value: WaitPolicy)
pub fn set_wait_for_stage(&mut self, value: WaitPolicy)
Sets wait_for_stage to the provided enum value.